@@ -19,19 +19,22 @@ module NumRu
       if assoc_crds.uniq.length != assoc_crds.length
 	raise ArgumentError, "Names are not uniq: #{assoc_crds.inspect}."
       end
+      @axnames = axnames.dup
       assoc_crds.each do |gp|
 	raise(ArgumentError,"Non-GPhys included") if !gp.is_a?(GPhys)
 	if axnames.include?(gp.name)
 	  raise ArgumentError, 
 	      "'#{gp.name}' overwraps an axis name #{axnames.inspect}."
 	end
+        if (gp.axnames - @axnames).length > 0
+          raise ArgumentError, "Provided assoc coord '#{gp.name}' has an axis (axes) #{gp.axnames - @axnames} not in the present object #{@axnames}"
+        end
       end
 
       # < some internal variables >
 
       @assoc_crds = Hash.new
       assoc_crds.each{|gp| @assoc_crds[gp.name] = gp}
-      @axnames = axnames.dup
       @lost_assoc_crds = nil
 
       # < lengths of original axes >
