@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 require "numru/gphys/gphys"
 require "numru/gphys/varrayhdfeos5"
 
@@ -95,7 +96,7 @@ module NumRu
 
         # (else)
         geo_names.each do |nm|
-          proc.call(nm)
+          proc.call(nm) if  swath.geo(nm).ntype != "char"
         end
 
 =begin
@@ -337,8 +338,8 @@ module NumRu
       end
 
       def __make_gd_axes(var0, grid, data)
-        dim_names = var0.dim_names # ̖O
-        unlocated_dim_names = var0.dim_names # ܂̌܂ĂȂ̖O
+        dim_names = var0.dim_names # 次元の名前
+        unlocated_dim_names = var0.dim_names # まだ軸の決まっていない次元の名前
         unused_var_names = grid.var_names
         axes = Array.new
 
@@ -358,7 +359,7 @@ module NumRu
         end
 
         # (#2) Empirical rule (from EOS-AURA, MLS, etc)
-        # (#2-1) m̎ɑ΂Aƈv閼O1ϐWϐƂč̗p
+        # (#2-1) 軸が未確定の次元に対し、次元名と一致する名前を持つ1次元変数を座標変数として採用する
         unlocated_dim_names.each do |dim_nm|
           if unused_var_names.include?(dim_nm)
             vary = __files2varray( grid, dim_nm)
@@ -370,7 +371,7 @@ module NumRu
           end
         end
 
-        # (#2-2) m̎ɑ΂A̎gĒ`Ă1ϐWϐƂč̗p
+        # (#2-2) 軸が未確定の次元に対し、その次元を使って定義されている1次元変数を座標変数として採用する
         # (a) select variables match to Regexp. 
         @@predef_gdcoords.each do |reg_exp|
           unlocated_dim_names.each do |dim_nm|
@@ -397,8 +398,8 @@ module NumRu
           end
         end
 
-        # (#2-3) Wϐ̓t@CɂȂ̂Ƃ݂ȂC
-        # _~[Ƃ 0,1,2,... 蓖Ă悤ɂD
+        # (#2-3) 座標変数はファイル中にないものとみなし，
+        # ダミーとして 0,1,2,... が割り当てられるようにする．
         unlocated_dim_names.each do |dim_nm|
           nary_length = data.shape_current[dim_names.index(dim_nm)]
           nary = NArray[0...nary_length]
@@ -413,14 +414,14 @@ module NumRu
       private :__make_gd_axes
 
       def __make_za_axes(var0, za, data)
-        dim_names = var0.dim_names # ̖O
-        unlocated_dim_names = var0.dim_names # ܂̌܂ĂȂ̖O
+        dim_names = var0.dim_names # 次元の名前
+        unlocated_dim_names = var0.dim_names # まだ軸の決まっていない次元の名前
         unused_var_names = za.var_names
         axes = Array.new
 
         # (#1) HDF-EOS5 standard rule is none.
         # (#2) Empirical rule (from EOS-AURA, MLS, etc)
-        # (#2-1) ƈv閼O1ϐWϐƂč̗p
+        # (#2-1) 次元名と一致する名前を持つ1次元変数を座標変数として採用する
         unlocated_dim_names.each do |dim_nm|
           if unused_var_names.include?(dim_nm)
             vary = __files2varray( za, dim_nm)
@@ -432,7 +433,7 @@ module NumRu
           end
         end
 
-        # (#2-2) m̎ɑ΂A̎gĒ`Ă1ϐWϐƂč̗p
+        # (#2-2) 軸が未確定の次元に対し、その次元を使って定義されている1次元変数を座標変数として採用する
         # (a) select variables match to Regexp. 
         @@predef_zacoords.each do |reg_exp|
           unlocated_dim_names.each do |dim_nm|
@@ -459,8 +460,8 @@ module NumRu
           end
         end
 
-        # (#2-3) Wϐ̓t@CɂȂ̂Ƃ݂ȂC
-        # _~[Ƃ 0,1,2,... 蓖Ă悤ɂD
+        # (#2-3) 座標変数はファイル中にないものとみなし，
+        # ダミーとして 0,1,2,... が割り当てられるようにする．
         unlocated_dim_names.each do |dim_nm|
           nary_length = data.shape_current[dim_names.index(dim_nm)]
           nary = NArray[0...nary_length]
@@ -474,7 +475,7 @@ module NumRu
       end
       private :__make_za_axes
 
-      # dim_index ɊւĎ1̕ϐȂ VArray ԂBłȂ nil ԂB
+      # dim_index に関して実質1次元の変数ならば VArray を返す。そうでなければ nil を返す。
       def __make_field_one_dimension(aHE5GdField, dim_index)
         rank = aHE5GdField.rank
         indexes = Array.new
