@@ -547,8 +547,15 @@ These methods returns a NArray (not a VArray).
 	end
 	myunits = self.units
 	if myunits != to
-	  gp = myunits.convert2(self, to)
-	  gp.units = to
+	  if calendar = self.get_att("calendar")
+	    date0 = UNumeric.new(0,myunits).to_datetime
+	    un0 = UNumeric.from_date(date0,to,calendar)
+	    offset = un0.to_f
+	    gp = self + offset
+	    gp.units = to
+	  else
+	    gp = myunits.convert2(self, to)
+	  end
 	  gp
 	else
 	  self   # returns self (no duplication)
@@ -619,22 +626,7 @@ These methods returns a NArray (not a VArray).
       end
 
       def axis_cyclic?
-	# Default setting is taken from a widely used netcdf convention.
-	# You can override it in a sub-class or using convention specific 
-	# mixins.
-	topology = attr['topology']
-	case topology
-	when /circular/i
-	  true
-	when nil     # 'topology' not defined
-	  if /degrees?_east/ =~ attr['units']
-	    true     # special treatment a common convention for the earth
-	  else
-	    nil      # not defined --> nil
-	  end
-	else
-	  false
-	end  
+        axis_modulo != nil
       end
 
       def axis_modulo
@@ -681,23 +673,16 @@ These methods returns a NArray (not a VArray).
       ## ToDo: coerce
 
       def coerce(other)
-	oattr = self.attr_copy
 	case other
 	when UNumeric
+          oattr = self.attr_copy
 	  oattr['units'] = other.units.to_s
 	  na_other, = NArray.new(self.typecode, 1).coerce(other.val)   # scalar
 	  c_other = VArray.new(na_other, oattr, self.name)
 	else
-	  oattr['units'] = self.get_att('units')     # Assume the same units
 	  case other
-	  when Numeric
-	    na_other, = NArray.new(self.typecode, 1).coerce(other)   # scalar
-	    c_other = VArray.new(na_other, oattr, self.name)
-	  when Array
-	    na = NArray.to_na(other)
-	    c_other = VArray.new(na, oattr, self.name)
-	  when NArray, NArrayMiss
-	    c_other = VArray.new(other, oattr, self.name)
+	  when Numeric, Array, NArrayMiss
+	    c_other = UNumeric::Num2Coerce.new( other )
 	  else
 	    raise "Cannot coerse #{other.class}"
 	  end
@@ -799,7 +784,7 @@ These methods returns a NArray (not a VArray).
 		 ary = NArrayMiss.to_nam(vl)#{f}(vr)
 	       end
 	       va = VArray.new( ary, self.attr_copy, self.name )
-	       va.units= self.units#{f}(other.units)
+	       va.units= self.units#{f}(other.units) if "#{f}" != "**" 
                va
 	    when Numeric, NArray, NArrayMiss, Array
 	       vl = self.val
@@ -810,7 +795,7 @@ These methods returns a NArray (not a VArray).
 		 ary = NArrayMiss.to_nam(vl)#{f}(vr)
 	       end
 	       va = VArray.new( ary, self.attr_copy, self.name )
-	       if "#{f}" == "**" 
+	       if "#{f}" == "**" && other.is_a?(Numeric)
 		 va.units= self.units#{f}(other)
                end
                va
@@ -1072,7 +1057,7 @@ if $0 == __FILE__
    p "*3*",vt.log10
    p "*4*",(vt < vs)
    vt.name='vvvttt'
-   p "*5*",(3+vt), vt.sin, vt.cos
+   p "*5*",(3+vt).units.to_s, (3*vt).units.to_s, vt.sin, vt.cos
    vc = vt.copy
    p 'atan2'
    vv = VArray.new( NArray.sfloat(5).indgen!, nil, 'vv' )
